<?php

namespace FiloBlu\Flow\Model\Parser;

use Exception;

/**
 * Class Csv
 * @package FiloBlu\Flow\Model\Parser
 */
class Csv extends AbstractParser
{
    /**
     * @param $resource string absolute path of the the csv file
     * @throws Exception
     */
    public function process($resource)
    {
        $channel = $this->getChannel();
        $count = 0;

        if (false === ($handle = @fopen($resource, 'rb'))) {
            throw new Exception("Unable to open {$resource}");
        }

        while (($data = fgetcsv($handle, 0, $this->separator, $this->delimiter)) !== false) {

            $count++;

            if ($count === 1) {

                if (!empty($this->header)) {
                    //throw new Exception("Header is already set but it should not: values => " . var_export($this->header, true));
                    $this->header = [];
                }

                foreach ($data as $header) {
                    $this->header[] = strtolower(trim($header));
                }
            }

            if ($count <= $this->linesToSkip) {
                continue;
            }

            try {
                array_walk($data, function (&$value, $key) {
                    $value = trim($value);
                });
                $this->parse($data);
            } catch (Exception $e) {
                throw new Exception($e->getMessage() . ' at row' . $count);
            }

        }

        fclose($handle);

        if (null !== $channel && method_exists($channel, 'commitData')) {
            $channel->commitData();
        }

    }

}
